function d3 = march(X, d)
% MARCH Performes the fast marching update step. X is a 3x3 matrix
% containing coordinates of one vertex of the triangle in each column.
% The last column contains the the vertex that is supposed to be updated.
% d is a 3-vector containing the current distances of each vertex (in the
% same order as they are in X). 

X = X-repmat(X(:,3),1,3); % Move x3 to origin
X = X(:, 1:2);

% Aligns the triangle such that the 3rd coordinate is zero for 
% x1 and x2, this is a basic assumption in the formulas
U = X(:,1)/norm(X(:,1));
V = cross(U,X(:,2))/norm(cross(U,X(:,2)));
W = cross(U,V);
R = [U,W,V]';
X = R*X;
V = X(1:2, 1:2);

% your code here!

end